django-jinja
============

Simple and nonobstructive jinja2 integration with Django.

**Now with support for django 1.8**


.. image:: https://img.shields.io/travis/niwibe/django-jinja.svg?style=flat
    :target: https://travis-ci.org/niwibe/django-jinja

.. image:: https://img.shields.io/pypi/v/django-jinja.svg?style=flat
    :target: https://pypi.python.org/pypi/django-jinja

.. image:: https://img.shields.io/pypi/dm/django-jinja.svg?style=flat
    :target: https://pypi.python.org/pypi/django-jinja


**Documentation:** http://niwibe.github.io/django-jinja/


How to install?
---------------

You can install it with pip:

.. code-block:: shell

    pip install django-jinja
